# voila-plain
Very simple template for Voila

This template removes the "page" view and eliminates superfluous margins and padding. It is designed for embedding a Voila app on a page with other things, such as is a [Dashboard app](https://github.com/timkpaine/dashboard)


[![](ss.png)]()